BarcodeScanResult class
BarcodeScanResult contains all decoded barcodes and their associated info.
Constructors
-
BarcodeScanResult({required EnumResultStatus status, List<
BarcodeResultItem> ? barcodes, int? errorCode, String? errorMessage}) - Creates a new instance of BarcodeScanResult.
Properties
-
barcodes
↔ List<
BarcodeResultItem> ? -
The decoded barcodes when the resultStatus is EnumResultStatus.finished.
getter/setter pair
- errorCode ↔ int?
-
Returns the error code when the resultStatus is EnumResultStatus.exception.
getter/setter pair
- errorMessage ↔ String?
-
Returns the errorString when the resultStatus is EnumResultStatus.exception.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ EnumResultStatus
-
The status of the barcode scan result.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited